/*******************************************************************************
* File Name: DispColon.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "DispColon.h"


/*******************************************************************************
* Function Name: DispColon_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void DispColon_Write(uint8 value) 
{
    uint8 staticBits = DispColon_DR & ~DispColon_MASK;
    DispColon_DR = staticBits | ((value << DispColon_SHIFT) & DispColon_MASK);
}


/*******************************************************************************
* Function Name: DispColon_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void DispColon_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(DispColon_0, mode);
}


/*******************************************************************************
* Function Name: DispColon_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DispColon_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DispColon_Read(void) 
{
    return (DispColon_PS & DispColon_MASK) >> DispColon_SHIFT;
}


/*******************************************************************************
* Function Name: DispColon_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DispColon_ReadDataReg(void) 
{
    return (DispColon_DR & DispColon_MASK) >> DispColon_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DispColon_INTSTAT) 

    /*******************************************************************************
    * Function Name: DispColon_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DispColon_ClearInterrupt(void) 
    {
        return (DispColon_INTSTAT & DispColon_MASK) >> DispColon_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
