/*******************************************************************************
* File Name: PilotLED.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "PilotLED.h"


/*******************************************************************************
* Function Name: PilotLED_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void PilotLED_Write(uint8 value) 
{
    uint8 staticBits = PilotLED_DR & ~PilotLED_MASK;
    PilotLED_DR = staticBits | ((value << PilotLED_SHIFT) & PilotLED_MASK);
}


/*******************************************************************************
* Function Name: PilotLED_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void PilotLED_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PilotLED_0, mode);
}


/*******************************************************************************
* Function Name: PilotLED_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PilotLED_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PilotLED_Read(void) 
{
    return (PilotLED_PS & PilotLED_MASK) >> PilotLED_SHIFT;
}


/*******************************************************************************
* Function Name: PilotLED_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PilotLED_ReadDataReg(void) 
{
    return (PilotLED_DR & PilotLED_MASK) >> PilotLED_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PilotLED_INTSTAT) 

    /*******************************************************************************
    * Function Name: PilotLED_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PilotLED_ClearInterrupt(void) 
    {
        return (PilotLED_INTSTAT & PilotLED_MASK) >> PilotLED_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
