/* ========================================
 *
 * Copyright fumi2kick, 2012
 * All Rights Reserved
 *
 * ========================================
*/
#include <device.h>


/* ---------------------- */
/* --- global value */
static unsigned char g_led_counter;
static unsigned char g_led;

static unsigned char g_segment[4];
static unsigned char g_segmentDrive;
static unsigned char g_dispcolon;
static unsigned char g_colonfade;

static unsigned char g_mode;
static unsigned char g_keep_hour;
static unsigned char g_keep_minute;

static unsigned char g_wait;

/* ---------------------- */
/* --- plottype */
extern void display_segment(int drive);
extern void display_colon(unsigned char power);
extern void doRefresh(void);

/* ---------------------- */
/* --- define */
static const unsigned char TRUE = 1;
static const unsigned char FALSE = 0;

static const unsigned char pattern[16] = {
    0x08, // 0 00001000
    0x5b, // 1 01011011
    0x22, // 2 00100010
    0x12, // 3 00010010
    0x51, // 4 01010001
    0x14, // 5 00010100
    0x04, // 6 00000100
    0x58, // 7 01011000
    0x00, // 8 00000000
    0x10, // 9 00010000
    0x40, // A 01000000
    0x05, // B 00000101
    0x2c, // C 00101100
    0x03, // D 00000011
    0x24, // E 00100100
    0x64, // F 01100100
};


/* ---------------------------------------- */
/* --- interrupt handler                    */
/* ---------------------------------------- */
void onInterrupt240Sync(void)
{
    g_segmentDrive = (g_segmentDrive + 1) & 3;
    display_segment(g_segmentDrive);
}

void onInterrupt60Sync(void)
{
    unsigned char c, sft;

    // colon
    if (g_colonfade > 0) {
        if (g_colonfade >= 2) {
            g_colonfade -= 2;
        }
        else {
            g_colonfade = 0;
        }
        display_colon(g_colonfade);
    }
    else {
        display_colon(0);
    }
    // pilot led
    g_led_counter = (g_led_counter + 1) & 0x3f;
    if ((g_led_counter & 0x0f) == 0) {
        c = (g_led_counter & 0xf0) >> 4;
        sft = 1 << c;
        if (g_led & sft) {
            PilotLED_Write(0);
        }
        else {
            PilotLED_Write(1);
        }
    }
    // UI wait timer
    if (g_wait > 0) {
        g_wait -= 1;
    }
}

void onInterruptRTC(void)
{
    g_colonfade = 64;
    doRefresh();
}

/* ---------------------------------------- */
/* --- LED driver                           */
/* ---------------------------------------- */
void display_segment(int drive)
{
    unsigned char dispbit;
    
    dispbit = 1 << drive;
    Segment_Write(0xff);
    SelectModule_Write(dispbit);
    Segment_Write(g_segment[drive]);
}

void set_segment(int select, int number, unsigned char period)
{
    unsigned char dat;

    if ((select < 0) || (select > 3)) {
        return;
    }
    dat = pattern[number] ^ 0xff;
    if (period) {
       dat |= 0x80;
    }
    else {
        dat &= 0x7f;
     }
    g_segment[select] = dat;
}

void display_colon(unsigned char power)
{
    if (g_dispcolon) {
        if (power == 0) {
            ColonOutputSelect_Write(0);
        }
        else {
            ColonOutputSelect_Write(1);
            PWM_1_WriteCompare1(power);
        }
    }
    else {
        ColonOutputSelect_Write(0);
    }
}

/* ---------------------------------------- */
/* --- sub routine                          */
/* ---------------------------------------- */

void disp_clock(void)
{
    unsigned char min, hour;
    g_dispcolon = TRUE;
    //
    hour = RTC_1_ReadHour();
    if (hour < 10) {
        g_segment[3] = 0x00;
    }
    else {
        set_segment(3, (hour / 10), FALSE);
    }
    set_segment(2, (hour % 10), FALSE);        
    //
    min = RTC_1_ReadMinute();
    set_segment(0, (min % 10), FALSE);
    set_segment(1, (min / 10), FALSE);
}

void disp_clock_mode1(void)
{
    unsigned char sec;
    g_dispcolon = FALSE;
    g_segment[2] = 0x00;
    g_segment[3] = 0x00;
    //
    sec = RTC_1_ReadSecond();
    set_segment(0, (sec % 10), TRUE);
    set_segment(1, (sec / 10), TRUE);
}

void disp_clock_mode2(void)
{
    unsigned char min, hour;
    g_dispcolon = TRUE;
    //
    hour = g_keep_hour;
    if (hour < 10) {
        g_segment[3] = 0x00;
    }
    else {
        set_segment(3, (hour / 10), TRUE);
    }
    set_segment(2, (hour % 10), TRUE);        
    //
    min = RTC_1_ReadMinute();
    set_segment(0, (min % 10), FALSE);
    set_segment(1, (min / 10), FALSE);
}

void disp_clock_mode3(void)
{
    unsigned char min, hour;
    g_dispcolon = TRUE;
    //
    hour = RTC_1_ReadHour();
    if (hour < 10) {
        g_segment[3] = 0x00;
    }
    else {
        set_segment(3, (hour / 10), FALSE);
    }
    set_segment(2, (hour % 10), FALSE);        
    //
    min = g_keep_minute;
    set_segment(0, (min % 10), TRUE);
    set_segment(1, (min / 10), TRUE);
}


// 表示更新、1秒ごとに呼ばれる。ただしコロンは含めない
void doRefresh(void)
{
    switch(g_mode) {
    case 0:
        disp_clock();
        break;
        
    case 1:
        disp_clock_mode1();
        break;

    case 2:
        disp_clock_mode2();
        break;

    case 3:
        disp_clock_mode3();
        break;
    }
}

// モード切替と各モードの設定＆初期化
void changeMode(void)
{
    switch(g_mode) {
    case 0:
        g_led = 0x0f;
        g_mode = 1;
        break;
        
    case 1:
        g_keep_hour = RTC_1_ReadHour();
        g_led = 0x0e;
        g_mode = 2;
        break;

    case 2:
        RTC_1_WriteHour(g_keep_hour);
        g_keep_minute = RTC_1_ReadMinute();
        g_led = 0x05;
        g_mode = 3;
        break;

    case 3:
        RTC_1_WriteMinute(g_keep_minute);
        g_led = 0x00;
        g_mode = 0;
        break;
    }
    doRefresh();
}


// セットボタンのアクション
void doPushButton(void)
{
    switch(g_mode) {
    case 1:
        RTC_1_WriteSecond(0);
        break;

    case 2:
        g_keep_hour = (g_keep_hour + 1) % 24;
        break;

    case 3:
        g_keep_minute = (g_keep_minute + 1) % 60;
        break;
    }
    doRefresh();
}


/* ---------------------------------------- */
/* --- main routine                         */
/* ---------------------------------------- */
void main()
{
    unsigned char inkey;

    g_led_counter = 0;
    g_led = 0;
    SelectModule_Write(0);
    Segment_Write(0xff);
    g_segmentDrive = 0;
    g_dispcolon = TRUE;
    g_colonfade = 0;
    
    clock_1_Start();
    PWM_1_Start();
    clock_2_Start();
    isr_60_Start();
    clock_3_Start();
    isr_240_Start();
    RTC_1_Start();
    RTC_1_EnableInt();
    RTC_1_WriteIntervalMask(RTC_1_INTERVAL_SEC_MASK);

    display_colon(0);
    g_led = 0x00;

    // start interrupt
    CyGlobalIntEnable;
    
    for(;;)
    {
        // mode button
        inkey = SW1_Read();
        if (inkey == 0) {
            changeMode();
            g_wait = 10;
            while(g_wait);
            while(SW1_Read() == 0);
        }
        // set button
        inkey = SW2_Read();
        if (inkey == 0) {
            doPushButton();
            g_wait = 4;
            while(g_wait);
            while(SW2_Read() == 0);
        }
    }
}

/* [] END OF FILE */
